窃听风暴 (豆瓣)
Description: 窃听风暴电影简介和剧情介绍,窃听风暴影评、图片、预告片、影讯、论坛、在线购票
Keywords: 窃听风暴,Das Leben der Anderen,窃听风暴影评,剧情介绍,电影图片,预告片,影讯,在线购票,论坛

No.66豆瓣电影Top250

# 窃听风暴 Das Leben der Anderen (2006)

导演: 弗洛里安·亨克尔·冯·多纳斯马尔克
编剧: 弗洛里安·亨克尔·冯·多纳斯马尔克
主演: 乌尔里希·穆埃 / 马蒂娜·格德克 / 塞巴斯蒂安·科赫 / 乌尔里希·图库尔 / 托马斯·蒂梅 / 汉斯-尤韦·鲍尔 / 沃克马·克莱纳特 / 马提亚斯·布伦纳 / 查理·哈纳 / 赫伯特·克瑙普 / 巴斯蒂安·特罗斯特 / 玛丽·格鲁伯 / 维尔纳·德恩 / 马丁·布拉姆马赫 / 托马斯·阿诺德 / 辛纳克·勋纳曼 / 路德韦格·布洛克伯格 / 迈克尔·格伯 / 吉塔·施维赫夫 / 希尔德加德·斯罗德 / 伊嘉·比肯费尔德 / 凯·伊沃·保利兹 / 克劳斯·芒斯特
类型: 剧情 / 悬疑
制片国家/地区: 德国
语言: 德语
上映日期: 2006-03-23(德国)
片长: 137分钟
又名: 窃听者(港) / 他人的生活 / 别人的生活 / 别样人生 / The Lives of Others
IMDb: tt0405094
豆瓣评分
引用
9.2
537263人评价
5星
64.7%
4星
29.5%
3星
5.3%
2星
0.4%
1星
0.2%
好于 98% 剧情片
好于 99% 悬疑片
想看 看过
评价:
推荐

## 窃听风暴的剧情简介 · · · · · ·

1984年的东德，整个社会笼罩在国家安全局的高压统治之下，特工魏斯曼（乌尔里希·穆埃 Ulrich Mühe 饰）奉命监听剧作家德莱曼（塞巴斯蒂安·科赫 Sebastian Koch 饰）及其女友演员克里斯蒂娜（马蒂娜·格德克 Martina Gedeck 饰）的生活，监听过程中，魏斯曼渐渐对这家人的生活产生了兴趣，开始暗中帮助他们。一篇刊登在西德《明镜》报上的文章引起了特工头目的注意，他们认为这篇文章是德莱曼写的，并逮捕了克里斯蒂娜，希望能够从她口中得出她丈夫的秘密？而审问克里斯蒂娜的正是魏斯曼…… ©豆瓣

## 窃听风暴的演职员 · · · · · · ( 全部 32 )

- 弗洛里安·亨克尔·冯·多纳斯马尔克 导演
- 乌尔里希·穆埃 饰 Hauptmann Gerd Wiesler
- 马蒂娜·格德克 饰 Christa-Maria Sieland
- 塞巴斯蒂安·科赫 饰 Georg Dreyman
- 乌尔里希·图库尔 饰 Oberstleutnant Anton Grubitz
- 托马斯·蒂梅 饰 Minister Bruno Hempf

## 窃听风暴的视频和图片 · · · · · · ( 预告片2 | 视频评论1 · 添加 | 图片889 · 添加 )

## 窃听风暴的获奖情况 · · · · · · ( 全部 )

- 第79届奥斯卡金像奖
- 最佳外语片
- 弗洛里安·亨克尔·冯·多纳斯马尔克

- 第64届金球奖
- 电影类 最佳外语片(提名)

- 第61届英国电影学院奖
- 电影奖 最佳影片(提名)
- 奎林·柏格 / 马克斯·威德曼

## 喜欢这部电影的人也喜欢 · · · · · ·

  记忆碎片

  控方证人

  致命魔术

  禁闭岛

  看不见的客人

  穆赫兰道

  非常嫌疑犯

  追随

  十二怒汉

  蝴蝶效应

我要写短评

## 窃听风暴的短评 · · · · · · ( 全部 126588 条 )

热门 / 最新 / 好友

### 7671 有用 毛毛毛读作cuì 看过 2011-04-22 12:53:01

饰演魏斯乐入木三分的名演员穆荷自己，在两德统一后去察看自己的“忠诚资料”，发现有长达六年的时间，每天向秘密警察报告他的言行举止的，正是他自己的妻子。

### 146 有用 国王KING 看过 2015-08-05 20:02:18

看着一堆一堆的好评让我忍不住困惑起来，难道我的评价鉴赏能力变差了么？的确觉得不好看，开头实在是异常的沉闷，让人难以忍受的节奏推进，除了开头的审问和窃听器安装，其他都乏善可陈。它絮絮叨叨地拍了一个小时，但我还是难以入戏。哎，人各有所爱。只能这样跟自己说了。

### 6936 有用 苏比 看过 2008-11-09 21:53:35

我们总是歌颂从未发生过的事。

### 343 有用 桃桃林林 看过 2006-12-18 09:34:39

远没有期待的好，一般而已

### 3492 有用 sogdiana 看过 2007-08-01 10:49:55

两条线，两个男人，两个故事，两个互相打捞的故事。丢了一个，彼此的人生都会沉入海底。当剧作家在街头，看到行走在人行道上的特工时，他本可以上前喊住他的。但是终于是没有。就像哈代所言，呼唤的人与被呼唤的很少能互相答应。他们最终选择了沉默地相互记录。

> 更多短评 126588条
为什么被折叠？ 有一些短评被折叠了
评论被折叠，是因为发布这条评论的帐号行为异常。评论仍可以被展开阅读，对发布人的账号不造成其他影响。如果认为有问题，可以联系豆瓣电影。
你关注的人还没写过短评
我要写影评

## 窃听风暴的影评 · · · · · · ( 全部 2340 条 )

热门 / 最新 / 好友
弯弯 2007-04-05 01:25:04

## 现实总比电影残酷

就算全世界都对《窃听风暴》交口称赞，假如一定有人跳出来唱反调，说那其实是一部失败的电影，那么，这个人多半就是前东德监狱博物馆的馆长。然而，假如没有这个馆长，《窃听风暴》这部电影最重要的意义便不会彰显。这是一部必须对照着来看的电影，唯有对照了史实与影片，才会... (展开)
6859 317 435回应 收起
小熊熊熊啊 2006-11-29 23:47:56

## 字幕做到吐...

隐居多少年，还是有人找到我，一顶高帽就把我忽悠来了 听译《Das Leben der Anderen》，一开始以为是爱情片，那肯定不难啊，再一看德语简介，完了，彻底疯了 早就不会做轴了，硬着头皮上吧，别人看电影时不会太注意的一句话，要反反复复听几十遍，也只有偏执狂爱做字幕吧 如果... (展开)
3551 293 648回应 收起
寒柯 2011-10-02 13:52:08

## 枪口抬高一公分

记得看过一个微博帖子，说;某师弟硕士毕业，将入司法机关，说心中茫然，问计于我。敬告四点：一、你不是医生，是疾病；二、不作恶，即善；三、能依法则依法，不能依法则依良心，若法律与良心都一片混沌，姑且视当事人为你的父母兄弟，依人性——假如你还有人性的话；四、如果迫... (展开)
1650 42 105回应 收起
rainman 2007-01-16 03:49:04

## 默默的伟大，静静的浪漫

感觉像是辛德勒的名单，不同的故事，相同的感动。 故事发生在前民主德国，在看了hustwj提供的背景资料之后（http://www.douban.com/subject/discussion/1047371/），片中的那种人人自危的紧张状况并不是导演在故意的夸大，前民主德国有85000名秘密警察和数十万名埋伏在社会各... (展开)
1069 117 130回应 收起
Claudia 2010-04-14 11:28:19

## 极权政治下的性苦闷

（本片最让人激赏的是三段“床戏”，这三段经过精心设计的“床戏”，充分展现了背景，生活完全不同的三个男人的性格特点，堪称塑造人物性格的经典，也是特色，尤其是女演员在奔驰车上被文化部部长“潜规则”那一段……） 关于1984年的东德，我认为完全可以用性虐理论去支持，... (展开)
839 64 107回应 收起
Wednesday 2006-12-29 13:01:34

## 《窃听风暴》——献给那个时代的所有人

近年来的几部优秀的德国电影，或写人或叙事，都带着对历史的重新审视和反思。无论是残酷的二战，还是荒谬的冷战时期，在批判和否定之余，更多了一层人性化的考量。 　　《窃听风暴》描述的是八十年代的东德，在那个人人自危的年代里，国家安全局扮演着重要又特殊的角色。影... (展开)
723 77 148回应 收起
drunkpiano 2009-05-30 02:19:36

## 没有你们就没有他们

又把《他人的生活》看了一遍，记忆中这是唯一一个我主动看第二遍的电影。重新看一遍的原因很简单：看第一遍时太囫囵吞枣了，没留心一个关键问题——那个“坏人”是怎么变成“好人”的。确切地说，我很想知道一个腐朽大厦的倒塌，是从哪个裂缝开始的。 《他人的生活》... (展开)
312 26 45回应 收起
吉米糕 2010-11-28 07:56:24

## 《窃听风暴》——你要做好人。

1984年的东德。 距离乔治奥威尔开始写作《1984》的1948年，36个年头又过去了。 距离中华人民共和国最高领袖发动的反右运动28年。 距离文化大革命爆发18年。 奥氏在书中描绘的大洋国，已在东方与西方开花。 相似的审讯，将人的尊严践踏到最卑微。 待遇等同的知识分子、艺... (展开)
285 25 60回应 收起
Eric 2006-12-19 22:26:50

## 别人的生活

德文名字叫Leben Der Anderen,Das （看不懂），英文叫The Lives of Others， 从英文直接翻译过来，中文应该叫《别人的生活》，或者为了突出窃听，可以叫做《活人秀》，这些都符合英文名原意。不过实际上中文被翻成了《窃听风暴》，奔着电影会有什么大场面的人一定会失望，而想... (展开)
216 79 98回应 收起
缈沨 2010-11-09 10:59:53

## 隐匿的人性——历史中的史塔西和柏林墙

在影片的译制过程中，很多时候模棱的片名翻译总会让观影者一不留神就忽略掉了一部经典好片。德国影片《窃听风暴》这名儿初听总会让人联想到美国滥俗的那种动作或谍战大片，且如此平白的译名更容易跟某国产片混淆。不少人与这部主题深沉而动人的影片就失之交臂了。 ... (展开)
102 3 5回应 收起

> 更多影评 2340篇

添加新讨论

## 讨论区 · · · · · ·

找不到你们所谓的感动点。 | 来自漫威死忠粉 | 70 回应 | 2022-11-20 00:58:44
《献给好人的奏鸣曲》 | 来自XYJ |  | 2022-11-11 20:57:18
求求大佬们，给个能看完整版的网站吧?，剪得稀巴烂。 | 来自抓紧爬 | 17 回应 | 2022-11-10 22:59:17
片中那个关于昂纳克的笑话 | 来自未央歌 | 25 回应 | 2022-11-10 21:37:21
v字仇杀队被删词条了，这部还会远吗 | 来自灵吾玄志 | 28 回应 | 2022-11-10 21:29:41

> 去这部影片的讨论区（全部443条）

## 关于《窃听风暴》的问题 · · · · · · ( 全部62个 )

- 特工男主的上司怎么看出特工变节的破绽的？ 19人回答
- 卫斯勒的策反是不是太容易了？ 26人回答

> 全部62个问题

## 在哪儿看这部电影 · · · · · ·

- 优酷视频 免费观看
- 腾讯视频 VIP免费观看
- 哔哩哔哩 免费观看

## 以下片单推荐 · · · · · · ( 全部 )

- ★豆瓣高分电影榜★ （上）9.7-8.6分 (影志)
- 【豆瓣五星电影集中营】(1/3) (影志)
- 【内牛满面】 (影志)
- 关于德国 你该看的 (≌菩提风花)
- 好看的欧洲片 (小老鼠)

## 谁在看这部电影 · · · · · ·

- 我妈叫我少吃点
  刚刚 想看
- 闻道
  刚刚 看过
- keo
  1分钟前 想看

815543人看过 / 424446人想看

订阅窃听风暴的评论:
feed: rss 2.0